QuotientOodFrame

Struct QuotientOodFrame 

pub struct QuotientOodFrame<E>
where E: FieldElement,
{ /* private fields */ }
Quotient polynomial evaluation frame at the out-of-domain points.

Stores the quotient polynomials evaluations at z and g * z, where z is a random Field element in current_row and next_row, respectively.

Implementations

Source

impl<E> QuotientOodFrame<E>
where E: FieldElement,

pub fn new(current_row: Vec<E>, next_row: Vec<E>) -> QuotientOodFrame<E>

Creates a new QuotientOodFrame from current, next.

pub fn current_row(&self) -> &[E]

Returns the current row.

pub fn next_row(&self) -> &[E]

Returns the next frame.

pub fn to_trace_states(&self) -> Vec<E>

Returns the frame as a vector of elements.