pub struct TraceOodFrame<E>where
E: FieldElement,{ /* private fields */ }Expand description
Trace evaluation frame at the out-of-domain point.
Stores the trace evaluations at z and gz, where z is a random Field element in
current_row and next_row, respectively.
Implementations
Sourceimpl<E> TraceOodFrame<E>where
E: FieldElement,
impl<E> TraceOodFrame<E>where
E: FieldElement,
Sourcepub fn new(
current_row: Vec<E>,
next_row: Vec<E>,
main_trace_width: usize,
) -> TraceOodFrame<E>
pub fn new( current_row: Vec<E>, next_row: Vec<E>, main_trace_width: usize, ) -> TraceOodFrame<E>
Creates a new TraceOodFrame from current, next.
Sourcepub fn num_columns(&self) -> usize
pub fn num_columns(&self) -> usize
Returns the number of columns for the current and next frames.
Sourcepub fn current_row(&self) -> &[E]
pub fn current_row(&self) -> &[E]
Returns the current row, consisting of both main and auxiliary columns.
Sourcepub fn next_row(&self) -> &[E]
pub fn next_row(&self) -> &[E]
Returns the next frame, consisting of both main and auxiliary columns.
Sourcepub fn main_frame(&self) -> EvaluationFrame<E>
pub fn main_frame(&self) -> EvaluationFrame<E>
Returns the evaluation frame for the main trace
Sourcepub fn aux_frame(&self) -> Option<EvaluationFrame<E>>
pub fn aux_frame(&self) -> Option<EvaluationFrame<E>>
Returns the evaluation frame for the auxiliary trace
Sourcepub fn to_trace_states(&self) -> Vec<E>
pub fn to_trace_states(&self) -> Vec<E>
Returns the main/aux frames as a vector of elements described in
OodFrame::set_trace_states.